@@ -72,6 +72,10 @@ static int	y_mem = Y_MEM;
 static int	x_swap = -1;
 static int	y_swap = -1;
 static int	y_message = Y_MESSAGE;
+static int	x_db = X_DB;
+static int	y_db = Y_DB;
+static int	x_io = X_IO;
+static int	y_io = Y_IO;
 static int	x_header = X_HEADER;
 static int	y_header = Y_HEADER;
 static int	x_idlecursor = X_IDLECURSOR;
@@ -1195,6 +1199,57 @@ u_swap(long *stats)
 	}
 }
 
+/*
+ *     *_db(db_info) - print "DB activity: " followed by database activity
+ */
+void
+i_db(struct db_info *db_info)
+{
+	u_db(db_info);
+}
+
+void
+u_db(struct db_info *db_info)
+{
+	char buf[128];
+
+	display_write(x_db, y_db, 0, 0, "DB activity: ");
+	snprintf(buf, sizeof(buf),
+			"%3ld tps, %2ld rollbs/s, %3ld buffer r/s, %2ld hit%%, %6ld row r/s, %4ld row w/s ",
+			 db_info->numXact, db_info->numRollback,
+			 db_info->numBlockRead,
+			 db_info->numBlockRead + db_info->numBlockHit > 0 ?
+					((int64_t)(db_info->numBlockHit * 100 /
+					(db_info->numBlockRead + db_info->numBlockHit))) : 0,
+			 db_info->numTupleFetched,
+			 db_info->numTupleAltered);
+	display_write(-1, -1, 0, 0, buf);
+}
+
+/*
+ *     *_io(io_info) - print "DB I/O: " followed by IO summary
+ */
+void
+i_io(struct io_info *io_info)
+{
+	char buf[128];
+	display_write(x_io, y_io, 0, 0, "DB I/O: ");
+
+	snprintf(buf, sizeof(buf),
+			"%5ld reads/s, %5ld KB/s, %5ld writes/s, %5ld KB/s  ",
+			io_info->reads,
+			io_info->readsectors / 2,
+			io_info->writes,
+			io_info->writesectors / 2);
+	display_write(-1, -1, 0, 0, buf);
+}
+
+void
+u_io(struct io_info *io_info)
+{
+	i_io(io_info);
+}
+
 /*
  *	*_message() - print the next pending message line, or erase the one
  *				  that is there.
