@@ -15,6 +15,8 @@
  * AUTHOR: Richard Henderson <rth@tamu.edu>
  * Order support added by Alexey Klimkin <kad@klon.tme.mcst.ru>
  * Ported to 2.4 by William LeFebvre
+ *
+ * Portions Copyright (c) 2013 VMware, Inc. All Rights Reserved.
  */
 
 #define _GNU_SOURCE
@@ -838,10 +840,10 @@ get_process_info(struct system_info *si,
 
 		if (rows > 0)
 		{
-			p = reallocarray(pgtable, rows, sizeof(struct top_proc));
+			p = realloc(pgtable, sizeof(struct top_proc) * rows);
 			if (p == NULL)
 			{
-				fprintf(stderr, "reallocarray error\n");
+				fprintf(stderr, "realloc error\n");
 				if (pgresult != NULL)
 					PQclear(pgresult);
 				disconnect_from_db(conninfo);
@@ -1370,3 +1372,76 @@ compare_writes(const void *v1, const void *v2)
 
 	return (result);
 }
+
+/*
+ * Get IO information for the SCSI devices in the system.  Returns
+ * read/write IOs per second and bandwidth by comparing current values
+ * with previous values.
+ */
+void
+get_io_info(struct io_info *io_info)
+{
+	struct timeval thistime;
+	double timediff;
+	static struct timeval lasttime;
+	struct io_info cur_info;
+	static struct io_info last_io_info;
+	FILE *fp;
+	char line[256];
+	int major, minor;
+	char dev_name[32];
+	int64_t reads, readsectors, skip, writes, writesectors;
+	int i;
+
+	/* calculate the time difference since our last check */
+	gettimeofday(&thistime, 0);
+	if (lasttime.tv_sec)
+		timediff = ((thistime.tv_sec - lasttime.tv_sec) +
+					(thistime.tv_usec - lasttime.tv_usec) * 1e-6);
+	else
+		timediff = 0;
+
+	lasttime = thistime;
+
+	fp = fopen("/proc/diskstats", "r");
+	if (fp == NULL)
+	{
+		memset(io_info, 0, sizeof(*io_info));
+		return;
+	}
+
+	memset(&cur_info, 0, sizeof(cur_info));
+	while (fgets(line, 256, fp) != NULL)
+	{
+		i = sscanf(line, "%d %d %31s %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld",
+				   &major, &minor, dev_name,
+				   &reads, &skip, &readsectors, &skip,
+				   &writes, &skip, &writesectors, &skip,
+				   &skip, &skip, &skip);
+		if (i != 14)
+			continue;
+
+		/* Total up full scsi devices (not partitions) */
+		if (major == 8 && (minor % 16) == 0)
+		{
+			cur_info.reads += reads;
+			cur_info.readsectors += readsectors;
+			cur_info.writes += writes;
+			cur_info.writesectors += writesectors;
+		}
+    }
+	fclose(fp);
+	if (timediff == 0)
+	{
+		last_io_info = cur_info;
+		memset(io_info, 0, sizeof(*io_info));
+		return;
+	}
+
+	/* Compute the rate information */
+	io_info->reads = (double)(cur_info.reads - last_io_info.reads) / timediff;
+	io_info->readsectors = (double)(cur_info.readsectors - last_io_info.readsectors) / timediff;
+	io_info->writes = (double)(cur_info.writes - last_io_info.writes) / timediff;
+	io_info->writesectors = (double)(cur_info.writesectors - last_io_info.writesectors) / timediff;
+	last_io_info = cur_info;
+}
