@@ -913,10 +913,10 @@ get_process_info_r(struct system_info *si, struct process_select *sel,
 
 	if (rows > 0)
 	{
-		p = reallocarray(pgrtable, rows, sizeof(struct top_proc_r));
+		p = realloc(pgrtable, sizeof(struct top_proc_r) * rows);
 		if (p == NULL)
 		{
-			fprintf(stderr, "reallocarray error\n");
+			fprintf(stderr, "realloc error\n");
 			if (pgresult != NULL)
 				PQclear(pgresult);
 			disconnect_from_db(conninfo);
@@ -975,9 +975,9 @@ get_process_info_r(struct system_info *si, struct process_select *sel,
 				break;
 			default:
 				if (sel->fullcmd && PQgetvalue(pgresult, i, c_fullcomm))
-					update_str(&n->name, PQgetvalue(pgresult, i, c_fullcomm));
+					update_str(&n->name, printable(PQgetvalue(pgresult, i, c_fullcomm)));
 				else
-					update_str(&n->name, PQgetvalue(pgresult, i, c_comm));
+					update_str(&n->name, printable(PQgetvalue(pgresult, i, c_comm)));
 
 				switch (PQgetvalue(pgresult, i, c_state)[0])
 				{
