@@ -1799,3 +1799,10 @@ reallocproc(int n)
 			op->oldpid = -1;
 	}
 }
+
+void
+get_io_info(struct io_info *io_info)
+{
+	/* Not supported yet */
+	memset(io_info, 0, sizeof(*io_info));
+}
