@@ -1437,3 +1437,10 @@ kmet_verify(
 	}
 	return;
 }
+
+void
+get_io_info(struct io_info *io_info)
+{
+	/* Not supported yet */
+	memset(io_info, 0, sizeof(*io_info));
+}
